@@ -1,6 +1,10 @@
 #ifndef _SEPOL_POLICYDB_POLCAPS_H_
 #define _SEPOL_POLICYDB_POLCAPS_H_
 
+#include <sys/cdefs.h>
+
+__BEGIN_DECLS
+
 /* Policy capabilities */
 enum {
 	POLICYDB_CAPABILITY_NETPEER,
@@ -17,4 +21,5 @@ extern int sepol_polcap_getnum(const char *name);
 /* Convert a capability number to name. */
 extern const char *sepol_polcap_getname(int capnum);
 
+__END_DECLS
 #endif /* _SEPOL_POLICYDB_POLCAPS_H_ */
