@@ -3,6 +3,9 @@
 
 #include <stddef.h>
 #include <stdio.h>
+#include <sys/cdefs.h>
+
+__BEGIN_DECLS
 
 #include <sepol/user_record.h>
 #include <sepol/context_record.h>
@@ -25,4 +28,5 @@
 /* Set internal policydb from a file for subsequent service calls. */
 extern int sepol_set_policydb_from_file(FILE * fp);
 
+__END_DECLS
 #endif
